@@ -116,7 +116,7 @@ FAILEDOPERATION_MASTERINSTANCEQUERYERROR = 'FailedOperation.MasterInstanceQueryE
 # 修改只读组配置失败。
 FAILEDOPERATION_MODIFYROGROUPERROR = 'FailedOperation.ModifyROGroupError'
 
-# 不符合资源所拥有的的网络数量要求。
+# 不符合资源所拥有的网络数量要求。
 FAILEDOPERATION_NETWORKNUMLIMITERROR = 'FailedOperation.NetworkNumLimitError'
 
 # 操作超过频率限制，请稍后重试。如果持续不成功，请联系客服进行处理。
@@ -215,6 +215,9 @@ FAILEDOPERATION_VPCRESETSERVICEERROR = 'FailedOperation.VPCResetServiceError'
 # VPC更新路由失败。
 FAILEDOPERATION_VPCUPDATEROUTEERROR = 'FailedOperation.VPCUpdateRouteError'
 
+# 查询白名单失败，请稍后重试。如果持续不成功，请联系客服进行处理。
+FAILEDOPERATION_WHITELISTCONNECTERROR = 'FailedOperation.WhitelistConnectError'
+
 # 流程创建失败。
 FLOWERROR = 'FlowError'
 
@@ -245,12 +248,18 @@ INTERNALERROR_FLOWERROR = 'InternalError.FlowError'
 # 管控系统元数据访问异常，请联系客服处理。
 INTERNALERROR_INSTANCEDATAERROR = 'InternalError.InstanceDataError'
 
+# 请求执行异常。
+INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
+
 # 后台数据解析失败，请联系客服进行处理。
 INTERNALERROR_MARSHALERROR = 'InternalError.MarshalError'
 
 # 系统错误。出现这种错误时，请联系客服支持。
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
+# 开启事务失败。
+INTERNALERROR_TRANSACTIOBEGINERROR = 'InternalError.TransactioBeginError'
+
 # 其他未知错误。出现这种错误时，请联系客服支持。
 INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'
 
@@ -365,6 +374,9 @@ INVALIDPARAMETERVALUE_INVALIDPID = 'InvalidParameterValue.InvalidPid'
 # 只读实例组状态错误。
 INVALIDPARAMETERVALUE_INVALIDREADONLYGROUPSTATUS = 'InvalidParameterValue.InvalidReadOnlyGroupStatus'
 
+# 无效地域。
+INVALIDPARAMETERVALUE_INVALIDREGIONIDERROR = 'InvalidParameterValue.InvalidRegionIdError'
+
 # 无效的可用区。
 INVALIDPARAMETERVALUE_INVALIDZONEIDERROR = 'InvalidParameterValue.InvalidZoneIdError'
 
@@ -452,6 +464,9 @@ OPERATIONDENIED_ROGROUPSTATUSERROR = 'OperationDenied.ROGroupStatusError'
 # 只读实例不支持ipv6。
 OPERATIONDENIED_ROINSTANCEIPV6NOTSUPPORTEDERROR = 'OperationDenied.ROInstanceIpv6NotSupportedError'
 
+# 只读实例状态限制当前操作。
+OPERATIONDENIED_ROINSTANCESTATUSLIMITOPERROR = 'OperationDenied.ROInstanceStatusLimitOpError'
+
 # 只读节点总数不能超过上限值。
 OPERATIONDENIED_ROINSTANCECOUNTEXEEDERROR = 'OperationDenied.RoInstanceCountExeedError'
 
